@@ -2,12 +2,18 @@ use strict;
 use warnings;
 package RT::Extension::MandatoryOnTransition;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 NAME
 
 RT-Extension-MandatoryOnTransition - Require core fields and ticket custom fields on status transitions
 
+=head1 RT VERSION
+
+Works with RT 4.0, 4.2, 4.4
+
+See below for some restrictions on RT 4.0.
+
 =head1 DESCRIPTION
 
 This RT extension enforces that certain fields have values before tickets are
@@ -72,7 +78,10 @@ Quick actions may be supported in a future release.
 
 =head2 Not all pages where you can change status are supported
 
-The ticket Basics page, for example.  See L</TODO> for others.
+SelfService, for example.  See L</TODO> for others.
+
+On 4.0, Basics and Jumbo are not supported because they do not have the
+needed code, which is present in 4.2.
 
 =head1 INSTALLATION
 
@@ -98,8 +107,18 @@ For RT 4.0, add this line:
 
 or add C<RT::Extension::MandatoryOnTransition> to your existing C<@Plugins> line.
 
-Then configure which fields should be mandatory on certain status changes
-(either globally or in a specific queue) using the C<%MandatoryOnTransition>
+=item Clear your mason cache
+
+    rm -rf /opt/rt4/var/mason_data/obj
+
+=item Restart your webserver
+
+=back
+
+=head1 CONFIGURATION
+
+To define which fields should be mandatory on certain status changes
+(either globally or in a specific queue) use the C<%MandatoryOnTransition>
 config option.  This option takes the generic form of:
 
     Set( %MandatoryOnTransition,
@@ -131,13 +150,14 @@ Category selection before resolving tickets in every other queue.
 The transition syntax is similar to that found in RT's Lifecycles.  See
 C<perldoc /opt/rt4/etc/RT_Config.pm>.
 
-=item Clear your mason cache
+=head2 C<$ShowAllCustomFieldsOnMandatoryUpdate>
 
-    rm -rf /opt/rt4/var/mason_data/obj
+By default, this extension shows only the mandatory fields on the update page
+to make it easy for users to fill them out when completing an action. If you
+would like to show all custom fields rather than just the mandatory ones,
+use this configuration option. You can set it like this:
 
-=item Restart your webserver
-
-=back
+    Set($ShowAllCustomFieldsOnMandatoryUpdate, 1);
 
 =head1 IMPLEMENTATION DETAILS
 
@@ -192,6 +212,11 @@ even if they are named exactly as listed in @CORE_SUPPORTED.  A supported
 field which doesn't appear in the mapping is skipped, the implication being
 that it isn't available during update.
 
+If your core field is called different things on Update.html and Modify.html
+you will need to modify the Modify.html/Default callback so the the
+extension knows what field to use.  Look at TimeWorked vs UpdateTimeWorked
+for an example.
+
 =item %CORE_FOR_CREATE
 
 A mapping similar to %CORE_FOR_UPDATE but consulted during ticket creation.
@@ -352,7 +377,7 @@ sub CheckMandatoryFields {
         (my $label = $field) =~ s/(?<=[a-z])(?=[A-Z])/ /g; # /
         push @errors,
           $CurrentUser->loc("[_1] is required when changing Status to [_2]",
-                                     $label, $ARGSRef->{Status});
+                                     $label, $CurrentUser->loc($ARGSRef->{Status}));
     }
 
     return \@errors unless @$cfs;
@@ -387,10 +412,19 @@ sub CheckMandatoryFields {
         }
 
         # Do we have a submitted value for update?
-        my $arg   = "Object-RT::Ticket-".$TicketId."-CustomField-".$cf->Id."-Value";
-        my $value = ($ARGSRef->{"${arg}s-Magic"} and exists $ARGSRef->{"${arg}s"})
-          ? $ARGSRef->{$arg . "s"}
-            : $ARGSRef->{$arg};
+        my $value;
+        if ( HTML::Mason::Commands->can('_ParseObjectCustomFieldArgs') ) {
+            # steal code from /Elements/ValidateCustomFields
+            my $CFArgs = HTML::Mason::Commands::_ParseObjectCustomFieldArgs( $ARGSRef )->{'RT::Ticket'}{$TicketId || 0} || {};
+            my $submitted = $CFArgs->{$cf->id};
+            # Pick the first grouping
+            $submitted = $submitted ? $submitted->{(sort keys %$submitted)[0]} : {};
+            $value = $submitted->{Values} // $submitted->{Value};
+        }
+        else {
+            my $arg   = "Object-RT::Ticket-".$TicketId."-CustomField-".$cf->Id."-Value";
+            $value = ($ARGSRef->{"${arg}s-Magic"} and exists $ARGSRef->{"${arg}s"}) ? $ARGSRef->{$arg . "s"} : $ARGSRef->{$arg};
+        }
 
         next if defined $value and length $value;
 
@@ -400,7 +434,7 @@ sub CheckMandatoryFields {
 
         push @errors,
           $CurrentUser->loc("[_1] is required when changing Status to [_2]",
-                                     $cf->Name, $ARGSRef->{Status});
+                                     $cf->Name, $CurrentUser->loc($ARGSRef->{Status}));
     }
 
     return \@errors;
@@ -437,8 +471,6 @@ sub Config {
 =item Enforcement on other update pages
 
     SelfService - can't do it without patches to <form> POST + additional callbacks
-    Basics      - need to patch callback for skipping (at least)
-    Jumbo       - need to patch callback for skipping (at least)
 
 =back
 
