@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 ### after: use lib qw(@RT_LIB_PATH@);
-use lib qw(/opt/rt4/local/lib /opt/rt4/lib);
+use lib qw(/Users/jbrandt/rts/rt440-test/local/lib /Users/jbrandt/rts/rt440-test/lib);
 
 package RT::Extension::MandatoryOnTransition::Test;
 
@@ -47,4 +47,14 @@ CONFIG
     require RT::Extension::MandatoryOnTransition;
 }
 
+sub RTAtorNewerThan{
+    my $version = shift;
+    my ($my_major, $my_minor, $my_sub) = split(/\./, $version);
+    my ($major, $minor, $sub) = split(/\./, $RT::VERSION);
+    return ($my_major >= $major
+            and $my_minor >= $minor
+            and $my_sub >= $sub)
+            ? 1 : 0;
+}
+
 1;
